photosgallery/contentharvesterplugin/inc/glxcontentharvesterplugindownloads.h
changeset 1 9ba538e329bd
parent 0 4e91876724a2
--- a/photosgallery/contentharvesterplugin/inc/glxcontentharvesterplugindownloads.h	Thu Dec 17 08:45:44 2009 +0200
+++ b/photosgallery/contentharvesterplugin/inc/glxcontentharvesterplugindownloads.h	Thu Jan 07 12:46:23 2010 +0200
@@ -198,11 +198,13 @@
 
     /// Owned: Media list
     MGlxMediaList* iMediaList;
-   
-    /// Own: the thumbnail context
-    CGlxThumbnailContext* iThumbnailContext;
+    
+    /// Own: Attribute Context
+	CGlxAttributeContext* iUriAttributeContext;
+	
+	CGlxAttributeContext* iThumbnailAttributeContext;
 
-    /// Own: Thuimbnail Iterator
+    /// Own: Thumbnail Iterator
     TGlxSequentialIterator iThumbnailIterator;
 
     RArray<TInt> iPreviewItemCount;